summaryrefslogtreecommitdiffstats
path: root/WebCore/html/HTMLViewSourceDocument.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'WebCore/html/HTMLViewSourceDocument.cpp')
-rw-r--r--WebCore/html/HTMLViewSourceDocument.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/WebCore/html/HTMLViewSourceDocument.cpp b/WebCore/html/HTMLViewSourceDocument.cpp
index 5391ddc..f66703a 100644
--- a/WebCore/html/HTMLViewSourceDocument.cpp
+++ b/WebCore/html/HTMLViewSourceDocument.cpp
@@ -36,7 +36,7 @@
#include "HTMLTableElement.h"
#include "HTMLTableRowElement.h"
#include "HTMLTableSectionElement.h"
-#include "HTMLDocumentParser.h"
+#include "LegacyHTMLDocumentParser.h"
#include "Text.h"
#include "TextDocument.h"
@@ -44,8 +44,8 @@ namespace WebCore {
using namespace HTMLNames;
-HTMLViewSourceDocument::HTMLViewSourceDocument(Frame* frame, const String& mimeType)
- : HTMLDocument(frame)
+HTMLViewSourceDocument::HTMLViewSourceDocument(Frame* frame, const KURL& url, const String& mimeType)
+ : HTMLDocument(frame, url)
, m_type(mimeType)
{
setUsesBeforeAfterRules(true);
@@ -53,14 +53,14 @@ HTMLViewSourceDocument::HTMLViewSourceDocument(Frame* frame, const String& mimeT
DocumentParser* HTMLViewSourceDocument::createParser()
{
// Use HTMLDocumentParser if applicable, otherwise use TextDocumentParser.
if (m_type == "text/html" || m_type == "application/xhtml+xml" || m_type == "image/svg+xml" || DOMImplementation::isXMLMIMEType(m_type)
#if ENABLE(XHTMLMP)
|| m_type == "application/vnd.wap.xhtml+xml"
#endif
) {
// FIXME: Should respect Settings::html5ParserEnabled()
- return new HTMLDocumentParser(this);
+ return new LegacyHTMLDocumentParser(this);
}
return createTextDocumentParser(this);
@@ -157,7 +157,7 @@ void HTMLViewSourceDocument::addViewSourceToken(Token* token)
} else {
const String& value = attr->value().string();
// Compare ignoring case since HTMLDocumentParser doesn't
// lower names when passing in tokens to
// HTMLViewSourceDocument.
if (equalIgnoringCase(token->tagName, "base") && equalIgnoringCase(attr->name().localName(), "href")) {
@@ -53,14 +53,14 @@ HTMLViewSourceDocument::HTMLViewSourceDocument(Frame* frame, const String& mimeT
DocumentParser* HTMLViewSourceDocument::createParser()
{
- // Use HTMLDocumentParser if applicable, otherwise use TextDocumentParser.
+ // Use LegacyHTMLDocumentParser if applicable, otherwise use TextDocumentParser.
if (m_type == "text/html" || m_type == "application/xhtml+xml" || m_type == "image/svg+xml" || DOMImplementation::isXMLMIMEType(m_type)
#if ENABLE(XHTMLMP)
@@ -157,7 +157,7 @@ void HTMLViewSourceDocument::addViewSourceToken(Token* token)
} else {
const String& value = attr->value().string();
- // Compare ignoring case since HTMLDocumentParser doesn't
+ // Compare ignoring case since LegacyHTMLDocumentParser doesn't
// lower names when passing in tokens to
// HTMLViewSourceDocument.